OC.L10N.register(
    "spreed",
    {
    "Everyone" : "Svi",
    "None" : "Ništa",
    "User" : "User",
    "Disabled" : "Onemogućeno",
    "Users" : "Korisnici",
    "Name" : "Ime",
    "Language" : "Jezik",
    "Country" : "Država",
    "Status" : "Status",
    "Pending" : "Na čekanju",
    "Error" : "Greška",
    "Blocked" : "Blokiran",
    "Saved" : "Spremljeno",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Loading",
    "Groups" : "Grupe",
    "Settings" : "Podešavanje",
    "Password protect" : "Zaštitita lozinkom",
    "Close" : "Zatvori",
    "Today" : "Danas",
    "Yesterday" : "Jučer",
    "Enabled" : "Aktivirano",
    "Save" : "Spremi",
    "Password" : "Lozinka",
    "Login" : "Login",
    "Nickname" : "Nadimak",
    "guest" : "gost",
    "Add users or groups" : "Add users or groups",
    "Edit" : "Izmjeni",
    "Keyboard shortcuts" : "Tipkovni prečaci",
    "Search" : "Search",
    "Share link" : "Podijelite vezu",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Default" : "Zadano",
    "Android app" : "Android aplikacija",
    "iOS app" : "iOS aplikacija",
    "Copied!" : "Kopirano",
    "Cancel" : "Otkaži",
    "Change password" : "Promijeni lozinku",
    "Rename" : "Preimenuj",
    "Send" : "Pošalji",
    "Share" : "Podjeli",
    "Error while sharing" : "Greška pri dijeljenju",
    "Favorited" : "Favorizovano",
    "Contacts" : "Kontakti"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
